@@ -29,6 +29,9 @@ import logging
 import time
 import urllib.request, urllib.parse, urllib.error
 import codecs
+import ssl
+
+from . import data
 
 HTTP_TIMEOUT = 30
 USER_AGENT = 'pithos'
@@ -78,8 +81,7 @@ class Pandora(object):
     - :py:meth:`json_call` call into the JSON API directly
     """
     def __init__(self):
-        self.opener = urllib.request.build_opener()
-        pass
+        self.opener = self.build_opener()
 
     def pandora_encrypt(self, s):
         return b''.join([codecs.encode(self.blowfish_encode.encrypt(pad(s[i:i+8], 8)), 'hex_codec') for i in range(0, len(s), 8)])
@@ -178,6 +180,18 @@ class Pandora(object):
         """
         self.audio_quality = fmt
 
+    @staticmethod
+    def build_opener(*handlers):
+        """Creates a new opener
+
+        Wrapper around urllib.request.build_opener() that adds
+        a custom ssl.SSLContext for use with internal-tuner.pandora.com
+        """
+        ctx = ssl.create_default_context()
+        ctx.load_verify_locations(cadata=data.internal_cert)
+        https = urllib.request.HTTPSHandler(context=ctx)
+        return urllib.request.build_opener(https, *handlers)
+
     def set_url_opener(self, opener):
         self.opener = opener
 
@@ -334,6 +348,8 @@ class Song(object):
         self.is_ad = None  # None = we haven't checked, otherwise True/False
         self.tired=False
         self.message=''
+        self.duration = None
+        self.position = None
         self.start_time = None
         self.finished = False
         self.playlist_time = time.time()
@@ -352,7 +368,7 @@ class Song(object):
                 self._title = self.songName
             else:
                 try:
-                    xml_data = urllib.urlopen(self.songExplorerUrl)
+                    xml_data = urllib.request.urlopen(self.songExplorerUrl)
                     dom = minidom.parseString(xml_data.read())
                     attr_value = dom.getElementsByTagName('songExplorer')[0].attributes['songTitle'].value
 
@@ -378,6 +394,14 @@ class Song(object):
     def station(self):
         return self.pandora.get_station_by_id(self.stationId)
 
+    def get_duration_sec (self):
+      if self.duration is not None:
+        return self.duration / 1000000000
+
+    def get_position_sec (self):
+      if self.position is not None:
+        return self.position / 1000000000
+
     def rate(self, rating):
         if self.rating != rating:
             self.station.transformIfShared()
