@@ -15,22 +15,22 @@
 ### END LICENSE
 
 import os
+import gi
 from gi.repository import Gtk
 from pithos.pithosconfig import get_data_file
 from pithos.plugin import PithosPlugin
 
-# Use appindicator if on Unity and installed
+# Use appindicator if installed
 try:
-    if os.environ['XDG_CURRENT_DESKTOP'] == 'Unity':
-        from gi.repository import AppIndicator3 as AppIndicator
-        indicator_capable = True
-    else:
-        indicator_capable = False
+    gi.require_version('AppIndicator3', '0.1')
+    from gi.repository import AppIndicator3 as AppIndicator
+    indicator_capable = True
 except:
     indicator_capable = False
 
 class PithosNotificationIcon(PithosPlugin):    
     preference = 'show_icon'
+    description = 'Adds pithos icon to system tray'
             
     def on_prepare(self):
         if indicator_capable:
@@ -73,13 +73,10 @@ class PithosNotificationIcon(PithosPlugin):
     def build_context_menu(self):
         menu = Gtk.Menu()
         
-        def button(text, action, icon=None):
-            if icon == 'check':
+        def button(text, action, checked=False):
+            if checked:
                 item = Gtk.CheckMenuItem(text)
                 item.set_active(True)
-            elif icon:
-                item = Gtk.ImageMenuItem(text)
-                item.set_image(Gtk.Image.new_from_stock(icon, Gtk.IconSize.MENU))
             else:
                 item = Gtk.MenuItem(text)
             item.connect('activate', action) 
@@ -89,20 +86,22 @@ class PithosNotificationIcon(PithosPlugin):
         
         if indicator_capable:
             # We have to add another entry for show / hide Pithos window
-            self.visible_check = button("Show Pithos", self._toggle_visible, 'check')
+            self.visible_check = button("Show Pithos", self._toggle_visible, True)
+
+            # On middle-click
+            self.ind.set_secondary_activate_target(self.visible_check)
         
-        self.playpausebtn = button("Pause", self.window.playpause, Gtk.STOCK_MEDIA_PAUSE)
-        button("Skip",  self.window.next_song,                     Gtk.STOCK_MEDIA_NEXT)
-        button("Love",  (lambda *i: self.window.love_song()),      Gtk.STOCK_ABOUT)
-        button("Ban",   (lambda *i: self.window.ban_song()),       Gtk.STOCK_CANCEL)
-        button("Tired", (lambda *i: self.window.tired_song()),     Gtk.STOCK_JUMP_TO)
-        button("Quit",  self.window.quit,                          Gtk.STOCK_QUIT )
+        self.playpausebtn = button("Pause", self.window.playpause)
+        button("Skip",  self.window.next_song)
+        button("Love",  (lambda *i: self.window.love_song()))
+        button("Ban",   (lambda *i: self.window.ban_song()))
+        button("Tired", (lambda *i: self.window.tired_song()))
+        button("Quit",  self.window.quit)
 
         # connect our new menu to the statusicon or the appindicator
         if indicator_capable:
             self.ind.set_menu(menu)
-            # Disabled because of https://bugs.launchpad.net/variety/+bug/1071598
-            #self.ind.connect('scroll-event', lambda _x, _y, steps: self.scroll(steps))
+            self.ind.connect('scroll-event', lambda _x, _y, steps: self.scroll(steps))
         else:
             self.statusicon.connect('popup-menu', self.context_menu, menu)
             self.statusicon.connect('scroll-event', lambda _, steps: self.scroll(steps))
@@ -116,11 +115,8 @@ class PithosNotificationIcon(PithosPlugin):
         button = self.playpausebtn
         if not playing:
             button.set_label("Play")
-            button.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_MEDIA_PLAY, Gtk.IconSize.MENU))
-
         else:
             button.set_label("Pause")
-            button.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_MEDIA_PAUSE, Gtk.IconSize.MENU))
             
         if indicator_capable: # menu needs to be reset to get updated icon
             self.ind.set_menu(self.menu)
