@@ -19,19 +19,24 @@ import html
 from sys import platform
 from pithos.plugin import PithosPlugin
 from pithos.pithosconfig import get_data_file
+
+import gi
+gi.require_version('Notify', '0.7')
 from gi.repository import (GLib, Gtk)
 
 class NotifyPlugin(PithosPlugin):
     preference = 'notify'
+    description = 'Shows notifications on song change'
 
     has_notifications = False
     supports_actions = False
+    escape_markup = False
 
     def on_prepare(self):
         if platform == 'darwin':
-            self.prepare_osx()
+            return self.prepare_osx()
         else:
-            self.prepare_notify()
+            return self.prepare_notify()
 
     def prepare_osx(self):
         try:
@@ -39,7 +44,7 @@ class NotifyPlugin(PithosPlugin):
             self.has_notifications = True
         except ImportError:
             logging.warning("pync not found.")
-            return
+            return "pync not found"
 
         self.notifier = Notifier
 
@@ -49,7 +54,7 @@ class NotifyPlugin(PithosPlugin):
             self.has_notifications = True
         except ImportError:
             logging.warning ("libnotify not found.")
-            return
+            return "libnotify not found"
 
         # Work-around Ubuntu's incompatible workaround for Gnome's API breaking mistake.
         # https://bugzilla.gnome.org/show_bug.cgi?id=702390
@@ -61,16 +66,19 @@ class NotifyPlugin(PithosPlugin):
                 old_add_action(*(args + (None,)))
         Notify.Notification.add_action = new_add_action
 
-        Notify.init('Pithos')
+        Notify.init('pithos')
         self.notification = Notify.Notification()
         self.notification.set_category('x-gnome.music')
-        self.notification.set_hint_string('desktop-icon', 'pithos')
+        self.notification.set_hint('desktop-entry', GLib.Variant.new_string('pithos'))
 
         caps = Notify.get_server_caps()
         if 'actions' in caps:
             logging.info('Notify supports actions')
             self.supports_actions = True
 
+        if 'body-markup' in caps:
+            self.escape_markup = True
+
         if 'action-icons' in caps:
             self.notification.set_hint('action-icons', GLib.Variant.new_boolean(True))
 
@@ -113,8 +121,10 @@ class NotifyPlugin(PithosPlugin):
         else:
             self.notification.set_hint('image-data', None)
 
-        msg = html.escape('by {} from {}'.format(song.artist, song.album))
-        self.notification.update(song.title, msg, 'audio-x-generic')
+        msg = 'by {} from {}'.format(song.artist, song.album)
+        if self.escape_markup:
+            msg = html.escape(msg, quote=False)
+        self.notification.update(song.title, msg, 'audio-x-generic' if not song.art_pixbuf else None)
         self.notification.show()
 
     def set_notification_osx(self, song, playing):
